@@ -69,7 +69,7 @@ void gx_cclosure_marshal_VOID__INT_INT(GClosure *closure,
 }
 
 
-G_DEFINE_TYPE(GxIREdit, gx_ir_edit, GTK_TYPE_DRAWING_AREA);
+G_DEFINE_TYPE(GxIREdit, gx_ir_edit, GTK_TYPE_DRAWING_AREA)
 
 static void gx_ir_edit_destroy(GtkWidget*);
 static gboolean ir_edit_event_draw(GtkWidget*, cairo_t*);
@@ -1410,7 +1410,7 @@ static gboolean ir_edit_motion_notify(GtkWidget *widget, GdkEventMotion *event)
 	GdkModifierType m;
     gdk_window_get_device_position(
         window, gtk_get_current_event_device(), &x, &y, &m);
-	if (x != event->x || y != event->y) {
+	if ((x != event->x || y != event->y) && ((event->state & GDK_BUTTON1_MASK) != GDK_BUTTON1_MASK)) {
 		// there shound be another event in the queue which updates
 		// to the aktual pointer position, so skip this one
 		gdk_event_request_motions(event);
