@@ -25,7 +25,7 @@
 #include <lv2.h>
 
 #define GXPLUGIN_URI "http://guitarix.sourceforge.net/plugins/gx_bmp_"
-#define GXPLUGIN_UI_URI "http://guitarix.sourceforge.net/plugins/gx_bmp_gui"
+#define GXPLUGIN_UI_URI "http://guitarix.sourceforge.net/plugins/gx_bmp_gui#_bmp_"
 
 
 typedef enum
