@@ -25,7 +25,7 @@
 #include <lv2.h>
 
 #define GXPLUGIN_URI "http://guitarix.sourceforge.net/plugins/gx_bossds1_"
-#define GXPLUGIN_UI_URI "http://guitarix.sourceforge.net/plugins/gx_bossds1_gui"
+#define GXPLUGIN_UI_URI "http://guitarix.sourceforge.net/plugins/gx_bossds1_gui#_bossds1_"
 
 
 typedef enum
@@ -34,7 +34,8 @@ typedef enum
    EFFECTS_INPUT,
    LEVEL, 
    TONE, 
-   DRIVE, 
+   DRIVE,
+   BYPASS,
 } PortIndex;
 
 #endif //SRC_HEADERS_GXEFFECTS_H_
