@@ -25,7 +25,7 @@
 #include <lv2.h>
 
 #define GXPLUGIN_URI "http://guitarix.sourceforge.net/plugins/gx_fumaster_"
-#define GXPLUGIN_UI_URI "http://guitarix.sourceforge.net/plugins/gx_fumaster_gui"
+#define GXPLUGIN_UI_URI "http://guitarix.sourceforge.net/plugins/gx_fumaster_gui#_fumaster_"
 
 
 typedef enum
