@@ -25,7 +25,7 @@
 #include <lv2.h>
 
 #define GXPLUGIN_URI "http://guitarix.sourceforge.net/plugins/gx_muff_"
-#define GXPLUGIN_UI_URI "http://guitarix.sourceforge.net/plugins/gx_muff_gui"
+#define GXPLUGIN_UI_URI "http://guitarix.sourceforge.net/plugins/gx_muff_gui#_muff_"
 
 
 typedef enum
