@@ -35,11 +35,13 @@ typedef enum
   BASS_L,
   MIDDLE_L,
   TREBLE_L,
+  MASTER_L,
   BRIGHT_R,
   VOLUME_R,
   BASS_R,
   MIDDLE_R,
   TREBLE_R,
+  MASTER_R,
   EFFECTS_OUTPUT,
   EFFECTS_INPUT,
   EFFECTS_OUTPUT1,
