@@ -32,7 +32,8 @@ typedef enum
 {
   AUTOWAH_OUTPUT,
   AUTOWAH_INPUT,
+  BYPASS,
   WAH,
-} EffectPortIndex;
+} PortIndex;
 
 #endif //SRC_HEADERS_GXAUTOWAH_H_
