@@ -35,6 +35,7 @@ typedef enum
   TS9_DRIVE,
   EFFECTS_OUTPUT,
   EFFECTS_INPUT,
-} EffectPortIndex;
+  BYPASS,
+} PortIndex;
 
 #endif //SRC_HEADERS_GXEFFECTS_H_
