@@ -69,15 +69,28 @@ static const char **_get_note_set(Widget_t *w) {
     
 }
 
+static float _adjust_scale(Widget_t *w, float fvis) {
+    XTuner *xt = (XTuner *)w->parent_struct;
+    if((int)xt->temperament == 0) return fvis;
+    else if((int)xt->temperament == 1) return fvis + 0.25;
+    else if((int)xt->temperament == 2) return fvis;
+    else if((int)xt->temperament == 3) return fvis + 0.05;
+    else if((int)xt->temperament == 4) return fvis + 0.02;
+    else if((int)xt->temperament == 5) return fvis + 0.095;
+    else return fvis;
+   
+}
+
 void _draw_tuner(void *w_, void* user_data) {
     Widget_t *w = (Widget_t*)w_;
     if (!w) return;
     XTuner *xt = (XTuner *)w->parent_struct;
-    XWindowAttributes attrs;
-    XGetWindowAttributes(w->app->dpy, (Window)w->widget, &attrs);
-    if (attrs.map_state != IsViewable) return;
-    int width = attrs.width;
-    int height = attrs.height;
+    Metrics_t m;
+    int width, height;
+    os_get_window_metrics(w, &m);
+    if (!m.visible) return;
+    width = m.width;
+    height = m.height;
     float x0 = width/2;
     float y0 = height/2;
 
@@ -119,8 +132,9 @@ void _draw_tuner(void *w_, void* user_data) {
         // (pitch tracker output 23 .. 999 Hz)
         indicate_oc = octsz - 1;
     }
-
+    fvis = _adjust_scale(w, fvis);
     scale = (fvis-vis) / 4;
+
     vis = vis % _get_tuner_temperament(w);
     if (vis < 0) {
         vis += _get_tuner_temperament(w);
