@@ -539,9 +539,11 @@ EngineControl::EngineControl()
       buffersize(0),
       samplerate(0),
       pluginlist(*this) {
+          pro.start();
 }
 
 EngineControl::~EngineControl() {
+    pro.stop();
 }
 
 void EngineControl::add_selector(ModuleSelector& sel) {
@@ -590,11 +592,14 @@ void EngineControl::set_buffersize(unsigned int buffersize_) {
 
 void EngineControl::init(unsigned int samplerate_, unsigned int buffersize_,
 			 int policy_, int priority_) {
+    pro.setThreadName("guitarixRT");
+    pro.setTimeOut(std::max(100,static_cast<int>((buffersize/(samplerate*0.000001))*0.1)));
     if (policy_ != policy || priority_ != priority) {
 	policy = policy_;
 	priority = priority_;
 	set_buffersize(buffersize_);
 	set_samplerate(samplerate_);
+    pro.setPriority(priority, policy);
 	return;
     }
     if (buffersize_ != buffersize) {
@@ -603,6 +608,7 @@ void EngineControl::init(unsigned int samplerate_, unsigned int buffersize_,
     if (samplerate_ != samplerate) {
 	set_samplerate(samplerate_);
     }
+    pro.setPriority(priority, policy);
 }
 
 void EngineControl::clear_rack_changed() {
@@ -685,34 +691,34 @@ void ModuleSequencer::set_samplerate(unsigned int samplerate) {
 
 bool ModuleSequencer::check_module_lists() {
     if (mono_chain.check_release()) {
-	mono_chain.release();
+        mono_chain.release();
     }
     if (stereo_chain.check_release()) {
-	stereo_chain.release();
+        stereo_chain.release();
     }
     if (get_rack_changed()) {
-	update_module_lists();
-	return mono_chain.check_release() || stereo_chain.check_release();
+        update_module_lists();
+        return mono_chain.check_release() || stereo_chain.check_release();
     }
     return false;
 }
 
 void ModuleSequencer::set_rack_changed() {
-#ifdef GUITARIX_AS_PLUGIN
+    #ifdef GUITARIX_AS_PLUGIN
     if (stateflags & SF_INITIALIZING) {
         return;
     }
-#endif
+    #endif
     if (rack_changed.connected()) {
-	return;
+        return;
     }
     rack_changed = Glib::signal_idle().connect(
-	sigc::mem_fun(this, &ModuleSequencer::check_module_lists));
+      sigc::mem_fun(this, &ModuleSequencer::check_module_lists));
 }
 
 bool ModuleSequencer::prepare_module_lists() {
     for (list<ModuleSelector*>::iterator i = selectors.begin(); i != selectors.end(); ++i) {
-	(*i)->set_module();
+        (*i)->set_module();
     }
     list<Plugin*> modules;
     pluginlist.ordered_mono_list(modules, audio_mode);
@@ -720,8 +726,8 @@ bool ModuleSequencer::prepare_module_lists() {
     pluginlist.ordered_stereo_list(modules, audio_mode);
     bool ret_stereo = stereo_chain.set_plugin_list(modules);
     if (ret_mono || ret_stereo) {
-	mono_chain.print();
-	stereo_chain.print();
+        mono_chain.print();
+        stereo_chain.print();
     }
     return ret_mono || ret_stereo;
 }
@@ -778,7 +784,9 @@ void __rt_func ModuleSequencer::overload(OverloadType tp, const char *reason) {
 	}
     }
     if (!ignore) {
+#ifndef GUITARIX_AS_PLUGIN
 	set_stateflag(SF_OVERLOAD);
+#endif
     }
     gx_system::atomic_set(&overload_reason, reason);
     overload_detected();
