@@ -34,47 +34,49 @@ namespace gx_engine {
  **  class NoiseGate
  */
 
-PluginDef NoiseGate::inputdef = PluginDef();
-float NoiseGate::fnglevel = 0;
-float NoiseGate::ngate = 1;
-bool NoiseGate::off = true;
-Plugin NoiseGate::inputlevel = Plugin();
-PluginDef NoiseGate::outputgate = PluginDef();
+NoiseGate::NoiseGate() : inputdef() , inputlevel() {
 
-NoiseGate::NoiseGate() {
-
-    inputdef.version = PLUGINDEF_VERSION;
-    inputdef.flags = PGN_SNOOP;
-    inputdef.id = "noise_gate";
-    inputdef.name = N_("Noise Gate");
-    inputdef.mono_audio = inputlevel_compute;
-    inputdef.register_params = noisegate_register;
+    off = true;
+    fnglevel = 0;
+    ngate = 1;
+    
+    version = PLUGINDEF_VERSION;
+    flags = PGN_SNOOP;
+    groups = 0;
+    category = "NONE";
+    id = "noise_gate";
+    name = N_("Noise Gate");
+    stereo_audio = 0;
+    mono_audio = inputlevel_compute;
+    register_params = noisegate_params_static;
+    set_samplerate = 0;
+    activate_plugin = noisegate_activate;
+    load_ui = 0;
+    clear_state = 0;
+    delete_instance = 0;
 
     inputlevel.set_pdef(&inputdef);
-
-    outputgate.version = PLUGINDEF_VERSION;
-    outputgate.id = "noiseshut";
-    outputgate.name = "?noiseshut";
-    outputgate.mono_audio = outputgate_compute;
-    outputgate.activate_plugin = outputgate_activate;
-
+    inputlevel = this;
 }
 
 inline float sqrf(float x) {
     return x * x;
 }
 
-void NoiseGate::inputlevel_compute(int count, float *input, float *output, PluginDef*) {
+void NoiseGate::inputlevel_process(int count, float *input, float *output) {
     float sumnoise = 0;
     for (int i = 0; i < count; i++) {
         sumnoise += sqrf(input[i]);
     }
-    if (sumnoise/count > sqrf(fnglevel * 0.01)) {
+    if (sumnoise/count > sqrf(fnglevel * 0.1)) {
         ngate = 1; // -75db 0.001 = 65db
     } else if (ngate > 0.01) {
         ngate *= 0.996;
     }
 }
+void NoiseGate::inputlevel_compute(int count, float *input, float *output, PluginDef* p) {
+    static_cast<NoiseGate*>(p)->inputlevel_process(count, input, output);
+}
 
 int NoiseGate::noisegate_register(const ParamReg& reg) {
     reg.registerFloatVar("noise_gate.threshold", N_("Threshold"), "S", "", &fnglevel,
@@ -82,20 +84,55 @@ int NoiseGate::noisegate_register(const ParamReg& reg) {
     return 0;
 }
 
-void NoiseGate::outputgate_compute(int count, float *input, float *output, PluginDef*) {
-    if (off) {
+int NoiseGate::noisegate_params_static(const ParamReg& reg) {
+    return static_cast<NoiseGate*>(reg.plugin)->noisegate_register(reg);
+}
+
+int NoiseGate::noisegate_start(bool start) {
+    off = !inputlevel.get_on_off();
+    return 0;
+}
+
+int NoiseGate::noisegate_activate(bool start, PluginDef *p) {
+    return static_cast<NoiseGate*>(p)->noisegate_start(start);
+}
+
+/****************************************************************
+ **  class OutPutGate
+ */
+
+OutPutGate::OutPutGate(const NoiseGate *noisegate_) :  outputdef(), outputlevel() {
+
+    version = PLUGINDEF_VERSION;
+    groups = 0;
+    category = "NONE";
+    id = "noiseshut";
+    name = "?noiseshut";
+    stereo_audio = 0;
+    mono_audio = outputgate_compute;
+    activate_plugin = 0;
+    register_params = 0;
+    set_samplerate = 0;
+    load_ui = 0;
+    clear_state = 0;
+    delete_instance = 0;
+
+    noisegate = noisegate_;
+    outputlevel.set_pdef(&outputdef);
+    outputlevel = this;
+}
+
+void OutPutGate::outputgate_process(int count, float *input, float *output) {
+    if (noisegate->off) {
         return;
     }
     while (count--) {
-        *output++ = ngate * *input++;
+        *output++ = noisegate->ngate * *input++;
     }
 }
 
-int NoiseGate::outputgate_activate(bool start, PluginDef *pdef) {
-    if (start) {
-        off = !inputlevel.get_on_off();
-    }
-    return 0;
+void OutPutGate::outputgate_compute(int count, float *input, float *output, PluginDef*p) {
+    static_cast<OutPutGate*>(p)->outputgate_process(count, input, output);
 }
 
 /****************************************************************
@@ -315,7 +352,7 @@ bool GxJConvSettings::operator==(const GxJConvSettings& jcset) const {
     if (fGainCor && std::abs(fGain - jcset.fGain) > 1e-4 * (fGain + jcset.fGain)) {
         return false;
     }
-    if (gainline == jcset.gainline) {
+    if (gainline != jcset.gainline) {
         return false;
     }
     return true;
@@ -466,8 +503,13 @@ void JConvParameter::setJSON_value() {
  ** class ConvolverAdapter
  */
 
+#ifndef GUITARIX_AS_PLUGIN
 #include "faust/jconv_post.cc"
 #include "faust/jconv_post_mono.cc"
+#else
+#include "jconv_post.cc"
+#include "jconv_post_mono.cc"
+#endif
 
 ConvolverAdapter::ConvolverAdapter(
     EngineControl& engine_, sigc::slot<void> sync_)
@@ -1000,6 +1042,7 @@ int FixedBaseConvolver::activate(bool start, PluginDef *p) {
         if (!self.start()) {
             return -1;
         }
+        if (!self.update_conn.connected())
         self.update_conn = Glib::signal_timeout().connect(
             sigc::mem_fun(self, &FixedBaseConvolver::check_update_timeout), 200);
     } else {
@@ -1069,7 +1112,11 @@ static CabEntry& getCabEntry(unsigned int n) {
 
 static const float no_sum = 1e10;
 
+#ifndef GUITARIX_AS_PLUGIN
 #include "faust/cabinet_impulse_former.cc"
+#else
+#include "cabinet_impulse_former.cc"
+#endif
 
 static int cab_load_ui(const UiBuilder& builder, int format) {
     if (format & UI_FORM_GLADE) {
@@ -1107,7 +1154,6 @@ CabinetConvolver::CabinetConvolver(EngineControl& engine, sigc::slot<void> sync,
     cabinet(0),
     bass(0),
     treble(0),
-    sum(no_sum),
     cab_names(new value_pair[cab_table_size+1]),
     impf(),
     smp() {
@@ -1144,23 +1190,21 @@ bool CabinetConvolver::do_update() {
         unsigned int fact = sru/sr;
         
         smp.setup(sr, fact*sr);
-        impf.init(cab.ir_sr);
+        impf.init(sr);
     }
-    float cab_irdata_c[cab.ir_count];
+    //float cab_irdata_c[cab.ir_count];
     impf.clear_state_f();
-    impf.compute(cab.ir_count,cab.ir_data,cab_irdata_c);
     while (!conv.checkstate());
     if (configure) {
-        if (!conv.configure(cab.ir_count, cab_irdata_c, cab.ir_sr)) {
+        if (!conv.configure(cab.ir_count, cab.ir_data, cab.ir_sr)) {
             return false;
         }
     } else {
-        if (!conv.update(cab.ir_count, cab_irdata_c, cab.ir_sr)) {
+        if (!conv.update(cab.ir_count, cab.ir_data, cab.ir_sr)) {
             return false;
         }
     }
     update_cabinet();
-    update_sum();
     return conv_start();
 }
 
@@ -1168,7 +1212,7 @@ bool CabinetConvolver::start(bool force) {
     if (force) {
         current_cab = -1;
     }
-    if (cabinet_changed() || sum_changed()) {
+    if (cabinet_changed()) {
         return do_update();
     } else {
         while (!conv.checkstate());
@@ -1180,7 +1224,7 @@ bool CabinetConvolver::start(bool force) {
 }
 
 void CabinetConvolver::check_update() {
-    if (cabinet_changed() || sum_changed()) {
+    if (cabinet_changed()) {
         do_update();
     }
 }
@@ -1193,6 +1237,7 @@ void CabinetConvolver::run_cab_conf(int count, float *input0, float *output0, Pl
         self.engine.overload(EngineControl::ov_Convolver, "cab");
     }
     self.smp.down(buf, output0);
+    self.impf.compute(count,output0,output0);
 }
 
 int CabinetConvolver::register_cab(const ParamReg& reg) {
@@ -1206,7 +1251,11 @@ int CabinetConvolver::register_cab(const ParamReg& reg) {
 }
 
 //// STEREO /////
+#ifndef GUITARIX_AS_PLUGIN
 #include "faust/cabinet_impulse_former_st.cc"
+#else
+#include "cabinet_impulse_former_st.cc"
+#endif
 
 static int cab_load_stereo_ui(const UiBuilder& builder, int format) {
     if (format & UI_FORM_GLADE) {
@@ -1244,7 +1293,6 @@ CabinetStereoConvolver::CabinetStereoConvolver(EngineControl& engine, sigc::slot
     cabinet(0),
     bass(0),
     treble(0),
-    sum(no_sum),
     cab_names(new value_pair[cab_table_size+1]),
     impf(),
     smp(),
@@ -1283,23 +1331,20 @@ bool CabinetStereoConvolver::do_update() {
         
         smp.setup(sr, fact*sr);
         smps.setup(sr, fact*sr);
-        impf.init(cab.ir_sr);
+        impf.init(sr);
     }
-    float cab_irdata_c[cab.ir_count];
     impf.clear_state_f();
-    impf.compute(cab.ir_count,cab.ir_data,cab_irdata_c);
     while (!conv.checkstate());
     if (configure) {
-        if (!conv.configure_stereo(cab.ir_count, cab_irdata_c, cab.ir_sr)) {
+        if (!conv.configure_stereo(cab.ir_count, cab.ir_data, cab.ir_sr)) {
             return false;
         }
     } else {
-        if (!conv.update_stereo(cab.ir_count, cab_irdata_c, cab.ir_sr)) {
+        if (!conv.update_stereo(cab.ir_count, cab.ir_data, cab.ir_sr)) {
             return false;
         }
     }
     update_cabinet();
-    update_sum();
     return conv_start();
 }
 
@@ -1307,7 +1352,7 @@ bool CabinetStereoConvolver::start(bool force) {
     if (force) {
         current_cab = -1;
     }
-    if (cabinet_changed() || sum_changed()) {
+    if (cabinet_changed()) {
         return do_update();
     } else {
         while (!conv.checkstate());
@@ -1319,7 +1364,7 @@ bool CabinetStereoConvolver::start(bool force) {
 }
 
 void CabinetStereoConvolver::check_update() {
-    if (cabinet_changed() || sum_changed()) {
+    if (cabinet_changed()) {
         do_update();
     }
 }
@@ -1335,6 +1380,7 @@ void CabinetStereoConvolver::run_cab_conf(int count, float *input0, float *input
     }
     self.smp.down(buf, output0);
     self.smps.down(buf1, output1);
+    self.impf.compute(count, output0, output1, output0, output1);
 }
 
 int CabinetStereoConvolver::register_cab(const ParamReg& reg) {
@@ -1392,7 +1438,11 @@ static PreEntry& getPreEntry(unsigned int n) {
     return pre_table[n];
 }
 
+#ifndef GUITARIX_AS_PLUGIN
 #include "faust/preamp_impulse_former.cc"
+#else
+#include "preamp_impulse_former.cc"
+#endif
 
 static int pre_load_ui(const UiBuilder& builder, int format) {
     if (format & UI_FORM_GLADE) {
@@ -1430,7 +1480,6 @@ PreampConvolver::PreampConvolver(EngineControl& engine, sigc::slot<void> sync,
     preamp(0),
     bass(0),
     treble(0),
-    sum(no_sum),
     pre_names(new value_pair[pre_table_size+1]),
     impf(),
     smp() {
@@ -1467,23 +1516,20 @@ bool PreampConvolver::do_update() {
         unsigned int fact = sru/sr;
         
         smp.setup(sr, fact*sr);
-        impf.init(pre.ir_sr);
+        impf.init(sr);
     }
-    float pre_irdata_c[pre.ir_count];
     impf.clear_state_f();
-    impf.compute(pre.ir_count,pre.ir_data,pre_irdata_c);
     while (!conv.checkstate());
     if (configure) {
-        if (!conv.configure(pre.ir_count, pre_irdata_c, pre.ir_sr)) {
+        if (!conv.configure(pre.ir_count, pre.ir_data, pre.ir_sr)) {
             return false;
         }
     } else {
-        if (!conv.update(pre.ir_count, pre_irdata_c, pre.ir_sr)) {
+        if (!conv.update(pre.ir_count, pre.ir_data, pre.ir_sr)) {
             return false;
         }
     }
     update_preamp();
-    update_sum();
     return conv_start();
 }
 
@@ -1491,7 +1537,7 @@ bool PreampConvolver::start(bool force) {
     if (force) {
         current_pre = -1;
     }
-    if (preamp_changed() || sum_changed()) {
+    if (preamp_changed()) {
         return do_update();
     } else {
         while (!conv.checkstate());
@@ -1503,7 +1549,7 @@ bool PreampConvolver::start(bool force) {
 }
 
 void PreampConvolver::check_update() {
-    if (preamp_changed() || sum_changed()) {
+    if (preamp_changed()) {
         do_update();
     }
 }
@@ -1516,6 +1562,7 @@ void PreampConvolver::run_pre_conf(int count, float *input0, float *output0, Plu
         self.engine.overload(EngineControl::ov_Convolver, "pre");
     }
     self.smp.down(buf, output0);
+    self.impf.compute(count,output0,output0);
 }
 
 int PreampConvolver::register_pre(const ParamReg& reg) {
@@ -1529,7 +1576,11 @@ int PreampConvolver::register_pre(const ParamReg& reg) {
 }
 
 //// STEREO /////
+#ifndef GUITARIX_AS_PLUGIN
 #include "faust/preamp_impulse_former_st.cc"
+#else
+#include "preamp_impulse_former_st.cc"
+#endif
 
 static int pre_load_stereo_ui(const UiBuilder& builder, int format) {
     if (format & UI_FORM_GLADE) {
@@ -1567,7 +1618,6 @@ PreampStereoConvolver::PreampStereoConvolver(EngineControl& engine, sigc::slot<v
     preamp(0),
     bass(0),
     treble(0),
-    sum(no_sum),
     pre_names(new value_pair[pre_table_size+1]),
     impf(),
     smp(),
@@ -1606,23 +1656,20 @@ bool PreampStereoConvolver::do_update() {
         
         smp.setup(sr, fact*sr);
         smps.setup(sr, fact*sr);
-        impf.init(pre.ir_sr);
+        impf.init(sr);
     }
-    float pre_irdata_c[pre.ir_count];
     impf.clear_state_f();
-    impf.compute(pre.ir_count,pre.ir_data,pre_irdata_c);
     while (!conv.checkstate());
     if (configure) {
-        if (!conv.configure_stereo(pre.ir_count, pre_irdata_c, pre.ir_sr)) {
+        if (!conv.configure_stereo(pre.ir_count, pre.ir_data, pre.ir_sr)) {
             return false;
         }
     } else {
-        if (!conv.update_stereo(pre.ir_count, pre_irdata_c, pre.ir_sr)) {
+        if (!conv.update_stereo(pre.ir_count, pre.ir_data, pre.ir_sr)) {
             return false;
         }
     }
     update_preamp();
-    update_sum();
     return conv_start();
 }
 
@@ -1630,7 +1677,7 @@ bool PreampStereoConvolver::start(bool force) {
     if (force) {
         current_pre = -1;
     }
-    if (preamp_changed() || sum_changed()) {
+    if (preamp_changed()) {
         return do_update();
     } else {
     while (!conv.checkstate());
@@ -1642,7 +1689,7 @@ bool PreampStereoConvolver::start(bool force) {
 }
 
 void PreampStereoConvolver::check_update() {
-    if (preamp_changed() || sum_changed()) {
+    if (preamp_changed()) {
         do_update();
     }
 }
@@ -1658,6 +1705,7 @@ void PreampStereoConvolver::run_pre_conf(int count, float *input0, float *input1
     }
     self.smp.down(buf, output0);
     self.smps.down(buf1, output1);
+    self.impf.compute(count, output0, output1, output0, output1);
 }
 
 int PreampStereoConvolver::register_pre(const ParamReg& reg) {
@@ -1674,7 +1722,11 @@ int PreampStereoConvolver::register_pre(const ParamReg& reg) {
  ** class ContrastConvolver
  */
 
+#ifndef GUITARIX_AS_PLUGIN
 #include "faust/presence_level.cc"
+#else
+#include "presence_level.cc"
+#endif
 
 ContrastConvolver::ContrastConvolver(EngineControl& engine, sigc::slot<void> sync,
     gx_resample::BufferResampler& resamp)
@@ -1764,7 +1816,6 @@ void ContrastConvolver::run_contrast(int count, float *input0, float *output0, P
 /****************************************************************
  ** class Directout
  */
-Plugin Directout::directoutput = Plugin();
 
 Directout::Directout(EngineControl& engine_, sigc::slot<void> sync_)
     : PluginDef(),
@@ -1773,14 +1824,19 @@ Directout::Directout(EngineControl& engine_, sigc::slot<void> sync_)
       sync(sync_),
       mem_allocated(false),
       plugin() {
-    directoutput.set_pdef(this);
     version = PLUGINDEF_VERSION;
+    groups = 0;
     flags = 0;
+    category = "NONE";
     id = "dout";
-    name = N_("Directoutputr");
+    name = N_("Directoutput");
     stereo_audio = compute_static;
+    mono_audio = 0;
     set_samplerate = init_static;
     activate_plugin = 0;
+    load_ui = 0;
+    register_params = 0;
+    plugin.set_pdef(this);
     plugin = this;
     engine.signal_buffersize_change().connect(
     sigc::mem_fun(*this, &Directout::change_buffersize));
@@ -1812,7 +1868,7 @@ void Directout::mem_alloc()
     try {
        outdata = new float[bsize]();
     } catch(...) {
-            gx_print_error("Directout", "cant allocate memory pool");
+            gx_print_error("Directout", "cannot allocate memory pool");
             return;
         }
     mem_allocated = true;
@@ -1874,8 +1930,11 @@ void __rt_func Directout::compute_static(int count, FAUSTFLOAT *input0, FAUSTFLO
  ** class DrumSequencer
  */
 
+#ifndef GUITARIX_AS_PLUGIN
 #include "faust/drumseq.cc"
-
+#else
+#include "drumseq.cc"
+#endif
 
 float* Drumout::set = 0;
 float* Drumout::data = 0;
@@ -2007,7 +2066,7 @@ void DrumSequencer::mem_alloc()
     try {
        outdata = new float[bsize]();
     } catch(...) {
-            gx_print_error("DrumSequencer", "cant allocate memory pool");
+            gx_print_error("DrumSequencer", "cannot allocate memory pool");
             return;
         }
     mem_allocated = true;
@@ -2106,7 +2165,7 @@ void always_inline DrumSequencer::compute(int count, FAUSTFLOAT *input0, FAUSTFL
         }
         int m = ftact;
         int r = rand()%(m+1 - (-m))+ (-m);
-        counter = 0; //int(r*fsliderhum);
+        counter -= iSlow15; //int(r*fsliderhum);
         
         if (step<seq_size) step = fmin(seq_size,fmax(0,step + 1.0 + int(r*fsliderhum)));
         else step = 0.0;
@@ -2423,7 +2482,7 @@ void smbPitchShift::mem_alloc()
         resampout = new float[fftFrameSize*4];
         indata2 = new float[fftFrameSize*4];
     } catch(...) {
-            gx_print_error("detune", "cant allocate memory pool");
+            gx_print_error("detune", "cannot allocate memory pool");
             return;
         }
     clear_state();
